@@ -230,12 +230,13 @@ impl<C> Api<C> for Server<C> where C: Has<XSpanIdString> + Send + Sync
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = context.clone();
-        info!("get_dioceses({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", province_id, province_code, name, location_name, location_address, location_email, offset, count, context.get().0.clone());
+        info!("get_dioceses({:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}, {:?}) - X-Span-ID: {:?}", province_id, province_code, name, location_name, location_address, location_email, sorts, offset, count, context.get().0.clone());
         Err("Generic failuare".into())
     }
 
