@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.7.0";
+pub const API_VERSION: &'static str = "0.8.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -425,6 +425,7 @@ pub trait Api<C: Send + Sync> {
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetDiocesesResponse, ApiError>;
@@ -609,6 +610,7 @@ pub trait ApiNoContext<C: Send + Sync> {
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>;
@@ -840,12 +842,13 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         location_name: Option<String>,
         location_address: Option<String>,
         location_email: Option<String>,
+        sorts: Option<&Vec<models::DioceseSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_dioceses(province_id, province_code, name, location_name, location_address, location_email, offset, count, &context).await
+        self.api().get_dioceses(province_id, province_code, name, location_name, location_address, location_email, sorts, offset, count, &context).await
     }
 
     /// Update an existing diocese
