@@ -697,6 +697,65 @@ impl std::convert::TryFrom<hyper::header::HeaderValue> for header::IntoHeaderVal
 }
 
 
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum DioceseSortCriteria {
+    #[serde(rename = "NAME_ASC")]
+    NAME_ASC,
+    #[serde(rename = "NAME_DESC")]
+    NAME_DESC,
+    #[serde(rename = "LOCATION_NAME_ASC")]
+    LOCATION_NAME_ASC,
+    #[serde(rename = "LOCATION_NAME_DESC")]
+    LOCATION_NAME_DESC,
+    #[serde(rename = "LOCATION_EMAIL_ASC")]
+    LOCATION_EMAIL_ASC,
+    #[serde(rename = "LOCATION_EMAIL_DESC")]
+    LOCATION_EMAIL_DESC,
+    #[serde(rename = "LOCATION_ADDRESS_ASC")]
+    LOCATION_ADDRESS_ASC,
+    #[serde(rename = "LOCATION_ADDRESS_DESC")]
+    LOCATION_ADDRESS_DESC,
+}
+
+impl std::fmt::Display for DioceseSortCriteria {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            DioceseSortCriteria::NAME_ASC => write!(f, "{}", "NAME_ASC"),
+            DioceseSortCriteria::NAME_DESC => write!(f, "{}", "NAME_DESC"),
+            DioceseSortCriteria::LOCATION_NAME_ASC => write!(f, "{}", "LOCATION_NAME_ASC"),
+            DioceseSortCriteria::LOCATION_NAME_DESC => write!(f, "{}", "LOCATION_NAME_DESC"),
+            DioceseSortCriteria::LOCATION_EMAIL_ASC => write!(f, "{}", "LOCATION_EMAIL_ASC"),
+            DioceseSortCriteria::LOCATION_EMAIL_DESC => write!(f, "{}", "LOCATION_EMAIL_DESC"),
+            DioceseSortCriteria::LOCATION_ADDRESS_ASC => write!(f, "{}", "LOCATION_ADDRESS_ASC"),
+            DioceseSortCriteria::LOCATION_ADDRESS_DESC => write!(f, "{}", "LOCATION_ADDRESS_DESC"),
+        }
+    }
+}
+
+impl std::str::FromStr for DioceseSortCriteria {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "NAME_ASC" => std::result::Result::Ok(DioceseSortCriteria::NAME_ASC),
+            "NAME_DESC" => std::result::Result::Ok(DioceseSortCriteria::NAME_DESC),
+            "LOCATION_NAME_ASC" => std::result::Result::Ok(DioceseSortCriteria::LOCATION_NAME_ASC),
+            "LOCATION_NAME_DESC" => std::result::Result::Ok(DioceseSortCriteria::LOCATION_NAME_DESC),
+            "LOCATION_EMAIL_ASC" => std::result::Result::Ok(DioceseSortCriteria::LOCATION_EMAIL_ASC),
+            "LOCATION_EMAIL_DESC" => std::result::Result::Ok(DioceseSortCriteria::LOCATION_EMAIL_DESC),
+            "LOCATION_ADDRESS_ASC" => std::result::Result::Ok(DioceseSortCriteria::LOCATION_ADDRESS_ASC),
+            "LOCATION_ADDRESS_DESC" => std::result::Result::Ok(DioceseSortCriteria::LOCATION_ADDRESS_DESC),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
+
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
 pub struct Institute {
